/**
 * Sprite.java
 *
 * @author Jeff Ondich
 * @version 25 October 2013
 */

import java.awt.*;

public abstract class Sprite {
    // We're using two Point objects for the position and size. It may be
    // that a single "Rectangle boundingBox" instance variable would have
    // been a better choice here, but sometimes you save improvements for
    // another day.
    private Point position;
    private Point size;
    private Point velocity;
    private String name;

    /**
     * Default constructor.
     */
    public Sprite() {
    }

    public String getName() {
        return this.name;
    }

    public void setName(String newName) {
        this.name = newName;
    }

    public Point getPosition() {
        return this.position;
    }

    public void setPosition(Point newPosition) {
        this.position = newPosition;
    }

    public Point getVelocity() {
        return this.velocity;
    }

    public void setVelocity(Point newVelocity) {
        this.velocity = newVelocity;
    }

    public Point getSize() {
        return this.size;
    }

    public void setSize(Point newSize) {
        this.size = newSize;
    }

    /**
     * Move the Sprite one step in the direction and magnitude
     * of its velocity.  Subclasses may override this method, which can
     * call super.step() and then perform any desired additional actions.
     */
    public void step() {
        this.position.setLocation(this.position.getX() + this.velocity.getX(),
                                  this.position.getY() + this.velocity.getY());
    }

    /**
     * Play a sound suitable for this sprite.
     */
    abstract public void makeSound();
 
    /**
     * Draw this sprite in the specified Graphics context.
     *
     * @param g the Graphics context into which to draw.
     */
    abstract public void draw(Graphics g);
}
